@@ -540,7 +540,7 @@ class MainModelFolder(Task, ModelFolder):
                         "Log in on Settings > Internet media > Last.fm"
                     self.callback_info(not_logged_message)
                 else:
-                    self.callback_info("No network available")
+                    self.callback_info("Network is down")
                 return
 
             lst = lastfm_manager.get_preference(TAG_LAST_PLAYED)
